@@ -45,7 +45,7 @@ int main(int argc, char *argv[])
 {
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
-    QQuickStyle::setStyle(QStringLiteral("Material"));
+    QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
 #else
     QApplication app(argc, argv);
     if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
@@ -55,8 +55,12 @@ int main(int argc, char *argv[])
 
 #ifdef Q_OS_WINDOWS
     if (AttachConsole(ATTACH_PARENT_PROCESS)) {
-        freopen("CONOUT$", "w", stdout);
-        freopen("CONOUT$", "w", stderr);
+        FILE *outFile = freopen("CONOUT$", "w", stdout);
+        if (!outFile)
+            qWarning() << "Failed to reopen stdout";
+        FILE *errFile = freopen("CONOUT$", "w", stderr);
+        if (!errFile)
+            qWarning() << "Failed to reopen stderr";
     }
 
     QApplication::setStyle(QStringLiteral("breeze"));
